Package: spectator
Title: Interface to the 'Spectator Earth' API
Version: 0.2.0
Authors@R: 
    person("Zivan", "Karaman", , "zivan.karaman@gmail.com", role = c("aut", "cre", "cph"),
           comment = c(ORCID = "0000-0002-8933-4589"))
Description: Provides interface to the 'Spectator Earth' API <https://api.spectator.earth/>, 
    mainly for obtaining the acquisition plans and satellite overpasses for Sentinel-1, 
    Sentinel-2, Landsat-8 and Landsat-9 satellites. Current position and trajectory can 
    also be obtained for a much larger set of satellites. It is also possible to search 
    the archive for available images over the area of interest for a given (past) period, 
    get the URL links to download the whole image tiles, or alternatively to download the 
    image for just the area of interest based on selected spectral bands.
License: GPL-3
Depends: R (>= 3.5.0)
Imports: geojsonsf, httr, sf
Suggests: calendar, calendR, httptest, knitr, lubridate, lutz, maps,
        rmarkdown
VignetteBuilder: knitr
Encoding: UTF-8
Language: en-US
LazyData: true
RoxygenNote: 7.2.2
NeedsCompilation: no
Packaged: 2023-07-04 15:51:43 UTC; zivan
Author: Zivan Karaman [aut, cre, cph] (<https://orcid.org/0000-0002-8933-4589>)
Maintainer: Zivan Karaman <zivan.karaman@gmail.com>
Repository: CRAN
Date/Publication: 2023-07-05 12:10:02 UTC
Built: R 4.6.0; ; 2026-04-26 10:32:15 UTC; unix
